@@ -4,7 +4,7 @@ f <- tempfile()
 
 w <- gwindow("CLT example")
 g <- ggroup(horizontal=FALSE, cont=w)
-l <- glabel("", cont = g)
+l <- glabel("Distribution of xbar, the sample mean.", cont = g)
 p <- gcanvas(width=500, height=400, cont = g)
 
 pops <- list("rnorm(n,0,1)" = list(cmd="rnorm", tooltip="Normal", mean=0, sd=1),
@@ -14,7 +14,7 @@ pops <- list("rnorm(n,0,1)" = list(cmd="rnorm", tooltip="Normal", mean=0, sd=1),
              "runif(n)" = list(cmd="runif", tooltip="Short tail"),
              "rlnorm(n)" = list(cmd="rlnorm", tooltip="Very skewed")
              )
-popsdf <- data.frame(names(pops),rep("",length(pops)),
+popsdf <- data.frame(names(pops),rep("plot",length(pops)),
                      tooltips=sapply(pops,function(i) i$tooltip), stringsAsFactors=FALSE)
 tbl <- glayout(cont = g)
 tbl[1,1] <- "n (sample size)"
@@ -31,11 +31,11 @@ makePlot <- function(h,...) {
   n <- min(as.numeric(svalue(sampleSize)), 500)
   m <- min(as.numeric(svalue(replicates)), 500)
   cmd <- pops[[svalue(population, index=TRUE)]]
-  theCall <- call(cmd$cmd, list(n=n,cmd[-(1:2)]))
-  x <- replicate(m, eval(theCall))
+  cmd$n <- n * m
+  x <- matrix(do.call(cmd$cmd, cmd[-(1:2)]), nrow=n)
   xbars <- apply(x, 2, function(x) mean(x))
   canvas(f, width=500, height=400, bg="#ffffff")
-  plot(density(xbars))
+  plot(density(xbars), main=sprintf("Population: %s, n: %s", svalue(population), svalue(sampleSize)))
   rug(xbars)
   dev.off()
   svalue(p) <- f
